package Mail::Chimp;

our $VERSION     = '0.50';

=head1 NAME

Mail::Chimp - Perl wrapper around the Mailchimp v1.2 API

=head1 DESCRIPTION

You should look at Mail::Chimp::API instead.

=head1 DEPENDENCIES

 Moose
 XMLRPC::Lite

=head1 SEE ALSO

 XMLRPC::Lite
 <http://www.mailchimp.com/api/rtfm/>

=head1 COPYRIGHT

Copyright (C) 2009 Dave Pirotte.  All rights reserved.

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=head1 AUTHOR

Dave Pirotte (dpirotte@gmail.com)

Drew Taylor (drew@drewtaylor.com)

Ask Bjørn Hansen (ask@develooper.com)

=cut

1;
